searchData={"items":[{"type":"module","title":"EnvLoader","doc":"A lightweight, dependency-free Elixir library for loading `.env` files into the system environment.\nBuilt for simplicity and robustness, it handles edge cases like comments, quoted values, `EXPORT`\ndirectives, empty keys, and inline comments with fewer than 60 lines of code.","ref":"EnvLoader.html"},{"type":"function","title":"EnvLoader.load/1","doc":"Loads environment variables from a .env file at the given path.","ref":"EnvLoader.html#load/1"},{"type":"function","title":"Parameters - EnvLoader.load/1","doc":"- `path`: Path to the .env file (e.g., \"./envs/.env\").","ref":"EnvLoader.html#load/1-parameters"},{"type":"function","title":"Returns - EnvLoader.load/1","doc":"- `:ok` on success, `:error` if the file is not found.","ref":"EnvLoader.html#load/1-returns"},{"type":"function","title":"Examples - EnvLoader.load/1","doc":"iex> File.write!(\"test.env\", \"KEY=value\")\n    iex> EnvLoader.load(\"test.env\")\n    :ok\n    iex> System.get_env(\"KEY\")\n    \"value\"\n    iex> File.rm!(\"test.env\")","ref":"EnvLoader.html#load/1-examples"},{"type":"extras","title":"EnvLoader","doc":"# EnvLoader\n\n[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/Eygem/env_loader/blob/main/LICENSE)\n[![Build Status](https://github.com/Eygem/env_loader/actions/workflows/ci.yml/badge.svg)](https://github.com/Eygem/env_loader/actions)\n\nA lightweight, dependency-free Elixir library for loading `.env` files into the system environment. Built for simplicity and robustness, it handles edge cases like comments, quoted values, `EXPORT` directives, empty keys, and inline comments with fewer than 60 lines of code.","ref":"readme.html"},{"type":"extras","title":"Installation - EnvLoader","doc":"Add `env_loader` to your `mix.exs` dependencies:\n```elixir\n{:env_loader, \"~> 0.1\"}\n```\nRun mix deps.get to fetch the dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - EnvLoader","doc":"`EnvLoader` loads environment variables from `.env` files into the system environment, typically in `config/runtime.exs`. This example loads variables from different files for production and development/testing environments. Variables can then be accessed via `System.get_env/1` or application config.\n\nAdd the following to `config/runtime.exs`:\n\n```elixir\nimport Config\nrequire Logger\n\nenv_file = if config_env() == :prod, do: \"./envs/.env\", else: \"./envs/.env.dev\"\n\ncase EnvLoader.load(env_file) do\n  :ok -> Logger.info(\"Successfully loaded .env file #{env_file}\")\n  :error -> Logger.error(\"Failed to load .env file #{env_file}\")\nend\n\n# Optional: Set application-specific config\nconfig :your_app, encryption_key: System.get_env(\"ENCRYPTION_KEY\") || \"default_key\"\n```\n\nAccess loaded variables in your application:\n```elixir\n# Using System.get_env/1\nkey = System.get_env(\"ENCRYPTION_KEY\")\n\n# Using application config (if defined)\nkey = Application.get_env(:your_app, :encryption_key)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Why Use config/runtime.exs? - EnvLoader","doc":"Elixir’s `config/runtime.exs` is evaluated at runtime, just before the application starts, making it ideal for loading environment variables because:\n- **Early Execution**: Runs before the supervision tree, ensuring variables are available to all processes.\n- **No Compile-Time Dependency**: Unlike `config/config.exs`, it doesn’t require variables during compilation.\n- **Idiomatic Elixir**: Integrates with the `Config` module for setting application configs (e.g., `config :your_app, ...`).","ref":"readme.html#why-use-config-runtime-exs"},{"type":"extras","title":"Supported .env Formats - EnvLoader","doc":"`EnvLoader` handles the following edge cases:\n- Quotes (`'value'`, `\"value\"`)\n- `EXPORT` directives (`EXPORT key=value`, `export key=value`)\n- Empty lines\n- Empty keys and values (`EMPTY_KEY=`, `=value`)\n- Full-line comments (`#comment`)\n- Inline comments (`key=value #comment`)\n- Malformed lines (`MALFORMED`)\n- Multiple `=` (`KEY=abc=def`)\n- Whitespace (`  KEY  =  value  `)\n- Whitespace in values (`key=value with spaces`)\n\nExample `.env` file:\n\n```shell\n# Comment\nENCRYPTION_KEY='secret123'\nAPI_KEY=\"key with spaces\"\nEMPTY_KEY=\n=value\nMALFORMED\nKEY_WITH_EQUALS=abc=def\nEXPORT EXPORT1_KEY=\"export1\"\nexport EXPORT2_KEY=\"export2\"\nSPACED_KEY  =  spaced value\nKEY_WITH_COMMENT=value # inline comment\n```\n\nRun `mix test` to verify these cases. Expected results:\n\n```elixir\nassert System.get_env(\"ENCRYPTION_KEY\") == \"secret123\"\nassert System.get_env(\"API_KEY\") == \"key with spaces\"\nassert System.get_env(\"EMPTY_KEY\") == nil\nassert System.get_env(\"KEY_WITH_EQUALS\") == \"abc=def\"\nassert System.get_env(\"EXPORT1_KEY\") == \"export1\"\nassert System.get_env(\"EXPORT2_KEY\") == \"export2\"\nassert System.get_env(\"SPACED_KEY\") == \"spaced value\"\nassert System.get_env(\"KEY_WITH_COMMENT\") == \"value\"\n```\n\nSee `test/env_loader_test.exs` for the full test suite.","ref":"readme.html#supported-env-formats"},{"type":"extras","title":"Contributing - EnvLoader","doc":"Contributions are welcome! Please open an issue or pull request on [GitHub](https://github.com/Eygem/env_loader). For major changes, discuss them in an issue first. Ensure tests pass with `mix test`.","ref":"readme.html#contributing"},{"type":"extras","title":"License - EnvLoader","doc":"Released under the MIT License. See the **[LICENSE](https://github.com/Eygem/env_loader/blob/main/LICENSE)** file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}